aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--androidmk/cmd/androidmk/android.go2
-rw-r--r--java/java.go7
2 files changed, 5 insertions, 4 deletions
diff --git a/androidmk/cmd/androidmk/android.go b/androidmk/cmd/androidmk/android.go
index 8bbd4e35..3423d790 100644
--- a/androidmk/cmd/androidmk/android.go
+++ b/androidmk/cmd/androidmk/android.go
@@ -44,7 +44,7 @@ var listProperties = map[string]string{
"LOCAL_CLANG_CFLAGS": "clang_cflags",
"LOCAL_YACCFLAGS": "yaccflags",
- "LOCAL_JAVA_RESOURCE_DIRS": "resource_dirs",
+ "LOCAL_JAVA_RESOURCE_DIRS": "java_resource_dirs",
"LOCAL_JAVACFLAGS": "javacflags",
"LOCAL_DX_FLAGS": "dxflags",
"LOCAL_JAVA_LIBRARIES": "java_libs",
diff --git a/java/java.go b/java/java.go
index 533cabbd..215924bb 100644
--- a/java/java.go
+++ b/java/java.go
@@ -55,8 +55,8 @@ type javaBase struct {
// or .aidl files.
Srcs []string `android:"arch_variant,arch_subtract"`
- // resource_dirs: list of directories containing resources
- Resource_dirs []string `android:"arch_variant"`
+ // java_resource_dirs: list of directories containing Java resources
+ Java_resource_dirs []string `android:"arch_variant"`
// no_standard_libraries: don't build against the default libraries (core-libart, core-junit,
// ext, and framework for device targets)
@@ -279,7 +279,8 @@ func (j *javaBase) GenerateJavaBuildActions(ctx common.AndroidModuleContext) {
classJarSpecs = append([]jarSpec{classes}, classJarSpecs...)
}
- resourceJarSpecs = append(ResourceDirsToJarSpecs(ctx, j.properties.Resource_dirs), resourceJarSpecs...)
+ resourceJarSpecs = append(ResourceDirsToJarSpecs(ctx, j.properties.Java_resource_dirs),
+ resourceJarSpecs...)
manifest := j.properties.Manifest
if manifest != "" {